@@ -7,6 +7,7 @@
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QUrl>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -83,27 +84,49 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     const QStringList args = parser.positionalArguments();
     QStringList paths;
-
+    
     if (!args.isEmpty())
-        paths = args;
+    {
+        for(const auto &path : args)
+            paths << QUrl::fromUserInput(path).toString();
+    }
+
+#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+    if (IndexInstance::attachToExistingInstance(QUrl::fromStringList(paths), false, false))
+    {
+        // Successfully attached to existing instance of Dolphin
+        return 0;
+    }else
+    {
+//        const QString serviceName = QStringLiteral("org.kde.index-%1").arg(QCoreApplication::applicationPid());
+//        auto instances = IndexInstance::appInstances(serviceName);
+//        if(instances.size() > 0)
+//        {
+//            instances.first().first->activateWindow();
+//        }
+    }
+
+    IndexInstance::registerService();
+#endif
+    Index *index = new Index();
 
-    Index index;
     QQmlApplicationEngine engine;
     const QUrl url(QStringLiteral("qrc:/main.qml"));
     QObject::connect(
-        &engine,
-        &QQmlApplicationEngine::objectCreated,
-        &app,
-        [url, paths, &index](QObject *obj, const QUrl &objUrl) {
-            if (!obj && url == objUrl)
-                QCoreApplication::exit(-1);
+                &engine,
+                &QQmlApplicationEngine::objectCreated,
+                &app,
+                [url, index](QObject *obj, const QUrl &objUrl) {
+        if (!obj && url == objUrl)
+            QCoreApplication::exit(-1);
 
-            if (!paths.isEmpty())
-                index.openPaths(paths);
-        },
-        Qt::QueuedConnection);
+        index->setQmlObject(obj);
 
-    engine.rootContext()->setContextProperty("inx", &index);
+    }, Qt::QueuedConnection);
+
+    engine.rootContext()->setContextProperty("initPaths", paths);
+
+    engine.rootContext()->setContextProperty("inx", index);
     qmlRegisterType<CompressedFile>(INDEX_URI, 1, 0, "CompressedFile");
     qmlRegisterType<FilePreviewer>(INDEX_URI, 1, 0, "FilePreviewProvider");
     qmlRegisterType<RecentFilesModel>(INDEX_URI, 1, 0, "RecentFiles");
@@ -116,8 +139,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     engine.load(url);
 
 #ifdef Q_OS_MACOS
-//        MAUIMacOS::removeTitlebarFromWindow();
-//        MauiApp::instance()->setEnableCSD(true); //for now index can not handle cloud accounts
+    //        MAUIMacOS::removeTitlebarFromWindow();
+    //        MauiApp::instance()->setEnableCSD(true); //for now index can not handle cloud accounts
 #endif
     return app.exec();
 }
